// Exif 2.2
function getExifInterpretedTagData(tagnum, data, dtype) {
	var output = '';
			switch (tagnum) {
			case 0x0000:	// GPSVersionID (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x00', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;			
			case 0x0001:	// InteroperabilityIndex (Iop IFD), GPSLatitudeRef (GPS IFD) 
				if (dtype == 'GPS') {
					output = getFormattedPString('x01', [data]);	// North or South latitude
				} else { 
					output = getFormattedPString('x0001', [data]);
				}
				break;
			case 0x0002:	// (Iop IFD?), GPSLatitude (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x02', [data , formatLatLong(data, 5)]);
				} else {
					output = getFormattedPString('x0002', [bytesToString(data)]);
				}
				break;
			case 0x0003:	// GPSLongitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x03', [data]);	// East or West
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0004:	// GPSLongitude (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x04', [data , formatLatLong(data, 5)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0005:	// GPSAltitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x05', [(data == 0 ? 'sea level' : 'sea level reference (negative value)')]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0006:	// GPSAltitude (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x06', [data , formatRational(data, 2)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0007:	// GPSTimeStamp (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x07', [data , formatTimestamp(data, 2)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0008:	// GPSSatellites (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x08', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0009:	// GPSStatus (GPS IFD)
				if (dtype == 'GPS') {
					var GPSStatuses = new Object();
					GPSStatuses.A = 'measurement in progress';
					GPSStatuses.V = 'measurement interoperability';
					output = getFormattedPString('x09', [getPString(GPSStatuses[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000A:	// GPSMeasureMode (GPS IFD)
				if (dtype == 'GPS') {
					var GPSMeasureModes = new Array('n/a (0)', '2-dimensional (1)', '3-dimensional (2)');
					output = getFormattedPString('x0A', [getPString(GPSMeasureModes[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000B:	// GPSDOP (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x0A', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000C:	// GPSSpeedRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSSpeedRefs = new Object();
					GPSSpeedRefs.K = 'kilometers per hour';
					GPSSpeedRefs.M = 'miles per hour';
					GPSSpeedRefs.N = 'knots';
					output = getFormattedPString('x0C', [getPString(GPSSpeedRefs[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000D:	// GPSSpeed (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x0D', [data , formatRational(data, 2)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000E:	// GPSTrackRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSTrackRefs = new Object();
					GPSTrackRefs.T = 'true direction';
					GPSTrackRefs.M = 'magnetic direction';
					output = getFormattedPString('x0E', [getPString(GPSTrackRefs[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x000F:	// GPSTrack (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x0F', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0010:	// GPSImgDirectionRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSImgDirectionRefs = new Object();
					GPSImgDirectionRefs.T = 'true direction';
					GPSImgDirectionRefs.M = 'magnetic direction';
					output = getFormattedPString('x10', [getPString(GPSImgDirectionRefs[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0011:	// GPSImgDirection (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x11', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0012:	// GPSMapDatum (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x12', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0013:	// GPSDestLatitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x13', [data]);	// North or South
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0014:	// GPSDestLatitude (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x14', [data , formatLatLong(data, 5)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0015:	// GPSDestLongitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x15', [data]); // East or West
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0016:	// GPSDestLongitude (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x16', [data , formatLatLong(data, 5)]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0017:	// GPSDestBearingRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSDestBearingRefs = new Object();
					GPSDestBearingRefs.T = 'true direction';
					GPSDestBearingRefs.M = 'magnetic direction';
					output = getFormattedPString('x17', [getPString(GPSDestBearingRefs[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0018:	// GPSDestBearing (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x18', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x0019:	// GPSDestDistanceRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSDestDistanceRefs = new Object();
					GPSDestDistanceRefs.K = 'kilometers';
					GPSDestDistanceRefs.M = 'miles';
					GPSDestDistanceRefs.N = 'knots';
					output = getFormattedPString('x19', [getPString(GPSDestDistanceRefs[data])]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x001A:	// GPSDestDistance (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x1A', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x001B:	// GPSProcessingMethod (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x1B', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x001C:	// GPSAreaInformation (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x1C', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x001D:	// GPSDateStamp (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x1D', [data]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x001E:	// GPSDifferential (GPS IFD)
				if (dtype == 'GPS') {
					output = getFormattedPString('x1E', [(data == 0 ? getPString('no differential correction (0)') : getPString('differential correction applied (1)'))]);
				} else {
					output = getFormattedPString('invalidGPStag', [zeroPad(tagnum) , data]);
				}
				break;
			case 0x00FE:	// (Iop IFD?)
				output = getFormattedPString('x00FE', [data]);
				break; 	
			case 0x00FF:	// (Iop IFD?)
				output = getFormattedPString('x00FF', [data]);
				break;
			case 0x0100:	// ImageWidth
				output = getFormattedPString('x0100', [data]);
				break;
			case 0x0101:	// ImageLength
				output = getFormattedPString('x0101', [data]);
				break;
			case 0x0102:	// BitsPerSample  
				output = getFormattedPString('x0102', [data]);
				break;
			case 0x0103:	// Compression
				var Compressions = new Array('n/a (0)', 'uncompressed (1)', 'n/a (2)', 'n/a (3)', 'n/a (4)', 'n/a (5)', 'JPEG compression (6)');
				output = getFormattedPString('x0103', [getPString(Compressions[data])]);
				break;
			case 0x0106:	// PhotometricInterpretation 
				var PhotometricInterpretations = new Array('n/a (0)', 'n/a (1)', 'RGB (2)', 'n/a (3)', 'n/a (4)', 'n/a (5)', 'YCbCr (6)');
				output = getFormattedPString('x0106', [getPString(PhotometricInterpretations[data])]);
				break;
			case 0x010E:	// ImageDescription 
				output = getFormattedPString('x010E', [data]);
				break;
			case 0x010F:	// Make
				output = getFormattedPString('x010F', [data]);
				break;
			case 0x0110:	// Model
				output = getFormattedPString('x0110', [data]);
				break;
			case 0x0111:	// StripOffsets
				output = getFormattedPString('x0111', [data]);
				break;
			case 0x0112:	// Orientation 
				var orientationFlags = new Array('undefined (0)', 'normal (1)', 'flipped horizontal (2)', 
								 'rotated 180&#176; (3)', 'flipped vertical (4)',
								 'transposed (5)', 'rotated 90&#176; (6)', 'transversed (7)',
								 'rotated 270&#176; (8)');   
				output = getFormattedPString('x0112', [getPString(data >= 0 &&  data <= 8 ? orientationFlags[data] : '(invalid value)')]);
				break;
			case 0x0115:	// SamplesPerPixel 
				output = getFormattedPString('x0115', [data]);
				break;
			case 0x0116:	// RowsPerStrip 
				output = getFormattedPString('x0116', [data]);
				break;
			case 0x0117:	// StripByteCounts 
				output = getFormattedPString('x0117', [data]);
				break;
			case 0x011A:	// XResolution
				output = getFormattedPString('x011A', [data , formatRational(data, 2)]);
				break;
			case 0x011B:	// YResolution
				output = getFormattedPString('x011B', [data , formatRational(data, 2)]);
				break;
			case 0x011C:	// PlanarConfiguration
				var PlanarConfigurations = new Array('n/a (0)', 'chunky format (1)', 'planar format (2)');
				output = getFormattedPString('x011C', [getPString(PlanarConfigurations[data])]);
				break;
			case 0x0128:	// ResolutionUnit 
				var ResolutionUnits = new Array('n/a (0)', 'none (1)', 'inch (2)', 'cm (3)');
				output = getFormattedPString('x0128', [getPString(ResolutionUnits[data])]);
				break;
			case 0x012D:	// TransferFunction 
				output = getFormattedPString('x012D', [data]);
				break; 	
			case 0x0131:	// Software
				output = getFormattedPString('x0131', [data]);
				break;
			case 0x0132:	// DateTime
				output = getFormattedPString('x0132', [data]);
				break;
			case 0x013B:	// Artist
				output = getFormattedPString('x013B', [data]);
				break;	
			case 0x013D:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x013D', [data]);
				break; 	
			case 0x013E:	// WhitePoint 
				output = getFormattedPString('x013E', [data , formatRationals(data, 3)]);
				break;
			case 0x013F:	// PrimaryChromaticities
				output = getFormattedPString('x013F', [data , formatRationals(data, 2)]);
				break;
			case 0x0142:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x0142', [data]);
				break; 	
			case 0x0143:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x0143', [data]);
				break; 	
			case 0x0144:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x0144', [data]);
				break;	
			case 0x0145:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x0145', [data]);
				break;	
			case 0x014A:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x014A', [data]);
				break;	
			case 0x015B:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x015B', [data]);
				break;	
			case 0x0201:	// JPEGInterchangeFormat 
				output = getFormattedPString('x0201', [data]);
				break;
			case 0x0202:	// JPEGInterchangeFormatLength
				output = getFormattedPString('x0202', [data]);
				break;
			case 0x0211:	// YCbCrCoefficients 
				output = getFormattedPString('x0211', [data , formatRationals(data, 3)]);
				break;
			case 0x0212:	// YCbCrSubSampling 
				// 2,1 = YCbCr4:2:2 
				// 2,2 = YCbCr4:2:0 
				output = getFormattedPString('x0212', [data]);
				break;
			case 0x0213:	// YCbCrPositioning
				var YCbCrPos = new Array('n/a (0)', 'centered / center of pixel array (1)', 'co-sited / datum point (2)');
				output = getFormattedPString('x0213', [getPString(YCbCrPos[data])]);
				break;
			case 0x0214:	// ReferenceBlackWhite 
				output = getFormattedPString('x0214', [data]);
				break;
			case 0x1000:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x1000', [data]);
				break;
			case 0x1001:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x1001', [data]);
				break;
			case 0x1002:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x1002', [data]);
				break;
			case 0x828D:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x828D', [data]);
				break; 	
			case 0x828E:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x828E', [data]);
				break;	
			case 0x828F:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x828F', [data]);
				break; 	
			case 0x8298:	// Copyright (Exif IFD)
				output = getFormattedPString('x8298', [data]);
				break;
			case 0x829A:	// ExposureTime (Exif IFD)
				var tmp = data.split('/');
				var val;
				if (tmp.length != 2  ||  tmp[0] == '1'  ||  (val = tmp[0] / tmp[1]) > 1) {
					output = getFormattedPString('x829A', [data , formatRational(data, 5)]);
				} else {
					var data2 = roundValue(1/val, 5); 
					output = getFormattedPString('y829A', [data , data2, formatRational(data, 5)]);
				}
				break;
			case 0x829D:	// FNumber (Exif IFD)
				output = getFormattedPString('x829D', [data , formatRational(data, 2)]);
				break;
			case 0x83BB:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x83BB', [data]);
				break;	
			case 0x8773:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x8773', [data]);
				break;	
			case 0x8822:	// ExposureProgram (Exif IFD)
				var ExpProgs = new Array('n/a (0)', 'manual control (1)', 'normal program (2)', 'aperture priority (3)', 
										 'shutter priority (4)', 'creative program (slow program, depth of field) (5)', 
										 'action program (high-speed program, fast shutter speed) (6)', 'portrait mode (7)', 
										 'landscape mode (8)');
				output = getFormattedPString('x8822', [getPString(ExpProgs[data])]);
				break;
			case 0x8824:	// SpectralSensitivity (Exif IFD)
				output = getFormattedPString('x8824', [data]);
				break;	
			case 0x8827:	// ISOSpeedRatings (Exif IFD)
				output = getFormattedPString('x8827', [data]);
				break;
			case 0x8828:	// OECF (Exif IFD)
				// similar to 0xA302
				output = getFormattedPString('x8828', [data]);
				break;	
			case 0x8829:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x8829', [data]);
				break; 	
			case 0x882A:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x882A', [data]);
				break; 	
			case 0x882B:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x882B', [data]);
				break; 	
			case 0x9000:	// ExifVersion (Exif IFD)
				output = getFormattedPString('x9000', [bytesToString(data)]);
				break;
			case 0x9003:	// DateTimeOriginal (Exif IFD)
				output = getFormattedPString('x9003', [data]);
				break;
			case 0x9004:	// DateTimeDigitized (Exif IFD)
				output = getFormattedPString('x9004', [data]);
				break;
			case 0x9101:	// ComponentsConfiguration (Exif IFD)
				output = getFormattedPString('x9101', [data ,
								data.replace(/0x01/g, 'Y').replace(/0x02/g, 'Cb').replace(/0x03/g, 'Cr')
									.replace(/0x04/g, 'R').replace(/0x05/g, 'G').replace(/0x06/g, 'B')
									.replace(/0x00/g, '').replace(/,/g, '')]);
				break;
			case 0x9102:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9102', [data , formatRational(data, 2)]);
				break;
			case 0x9201:	// ShutterSpeedValue (Exif IFD)
				var tmp = data.split('/');
				output = getFormattedPString('x9201', [data , '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' ,
						 			roundValue(Math.pow(2, tmp[0]/tmp[1]), 2)]);
				break;
			case 0x9202:	// ApertureValue (Exif IFD)
				var tmp = data.split('/');
				output = getFormattedPString('x9202', [data , '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' ,
						 			roundValue(Math.pow(2, tmp[0]/tmp[1]/2), 2)]);
				break;
			case 0x9203:	// BrightnessValue (Exif IFD)
				var tmp = data.split('/');
				output = getFormattedPString('x9203', [data , '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' ,
						 			roundValue(Math.pow(2, tmp[0]/tmp[1]), 2)]);
				break;
			case 0x9204:	// ExposureBiasValue (Exif IFD)
				output = getFormattedPString('x9204', [data , formatRational(data, 2)]);
				break;
			case 0x9205:	// MaxApertureValue (Exif IFD)
				var tmp = data.split('/');
				output = getFormattedPString('x9205', [data , formatRational(data, 2) , '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' ,
						 			roundValue(Math.pow(2, tmp[0]/tmp[1]/2), 2)]);
				break;
			case 0x9206:	// SubjectDistance (Exif IFD)
				output = getFormattedPString('x9206', [data]);
				break;
			case 0x9207:	// MeteringMode (Exif IFD)
				var MeteringModes = new Array('unknown (0)', 'average (1)', 'center weighted average (2)', 
									'spot (3)', 'multi-spot (4)', 'pattern / multi-segment (5)', 'partial (6)');
				MeteringModes[255] = 'other (255)';
				output = getFormattedPString('x9207', [(MeteringModes[data] ? getPString(MeteringModes[data]) : getPString('n/a') + ' (' + data + ')')]);
				break;
			case 0x9208:	// LightSource (Exif IFD)
				var LightSources = new Array('unknown (0)', 'daylight (1)', 'fluorescent (2)', 
											 'tungsten / incandescent (3)', 'flash (4)',
											 'n/a (5)', 'n/a (6)', 'n/a (7)', 'n/a (8)', 
											 'fine weather (9)', 'cloudy weather (10)', 'shade(11)', 
											 'daylight fluorescent (12)', 'day white fluorescent (13)',
											 'cool white fluorescent (14)', 'white fluorescent (15)',
											 'n/a (16)', 'standard light A (17)', 'standard light B (18)',
											 'standard light C (19)', 'D55 (20)', 'D65 (21)',
											 'D75 (22)', 'D50 (23)', 'ISO studio tungsten (24)');
				LightSources[255] = 'other (255)';
				output = getFormattedPString('x9208', [(LightSources[data] ? getPString(LightSources[data]) : getPString('n/a') + ' (' + data + ')')]);
				break;
			case 0x9209:	// Flash (Exif IFD)
				var Flashes = new Array();
				Flashes[0x00] = 'flash00';				Flashes[0x01] = 'flash01';
				Flashes[0x05] = 'flash05';				Flashes[0x07] = 'flash07';
				Flashes[0x09] = 'flash09';				Flashes[0x0D] = 'flash0D'; 
				Flashes[0x0F] = 'flash0F';				Flashes[0x10] = 'flash10'; 
				Flashes[0x18] = 'flash18';				Flashes[0x19] = 'flash19';
				Flashes[0x1D] = 'flash1D';				Flashes[0x1F] = 'flash1F'; 
				Flashes[0x20] = 'flash20';				Flashes[0x41] = 'flash41';
				Flashes[0x45] = 'flash45';				Flashes[0x47] = 'flash47';
				Flashes[0x49] = 'flash49';				Flashes[0x4D] = 'flash4D'; 
				Flashes[0x4F] = 'flash4F';				Flashes[0x59] = 'flash59';
				Flashes[0x5D] = 'flash5D';				Flashes[0x5F] = 'flash5F'; 				
				Flashes[0xFF] = 'flashFF';
//								'flash did not fire (0)', 'flash fired (1)', 'n/a (2)',
//								'n/a (3)', 'n/a (4)', 'flash fired but strobe return light not detected (5)', 
//								'n/a (6)', 'flash fired and strobe return light detected (7)');
				output = getFormattedPString('x9209', [Flashes[data] ? getPString(Flashes[data]) : getPString('n/a') + ' (' + data + ')']);
				break;
			case 0x920A:	// FocalLength (Exif IFD)
				output = getFormattedPString('x920A', [data , formatRational(data, 2)]);
				break;
			case 0x920B:	// FlashEnergy (Exif IFD) ???
				output = getFormattedPString('x920B', [data]);
				break; 	
			case 0x920C:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x920C', [data]);
				break;	
			case 0x920D:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x920D', [data]);
				break;	
			case 0x9211:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9211', [data]);
				break; 	
			case 0x9212:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9212', [data]);
				break; 	
			case 0x9213:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9213', [data]);
				break;	
			case 0x9214:	// SubjectArea (Exif IFD)
				if (data  &&  data.split) {
					var tmp = data.split(',');
					var Counts = new Array('n/a (0)', 'n/a (1)', 'x/y coordinates of main subject (2)',
								'x/y coordinates of center and radius of circle (3)', 
								'x/y coordinates of center and width/height of rectangle (4)');
					output = getFormattedPString('x9214_1', [data , getPString(Counts[tmp.length])]);
				} else {
					output = getFormattedPString('x9214_2', [data ? data : getPString('n/a')]);
				}
				break; 	
			case 0x9215:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9215', [data]);
				break; 	
			case 0x9216:	// (Not in Exif 2.2 specifications)
				output = getFormattedPString('x9216', [data]);
				break; 	
			case 0x927C:	// MakerNote (Exif IFD)
				output = getFormattedPString('x927C', [data]);
				break;
			case 0x9286:	// UserComment (Exif IFD)
				var char_code = 'unknown';
				if (data) {
					if (data.indexOf) {
						if (data.indexOf('0x41,0x53,0x43,0x49,0x49,0x00,0x00,0x00') == 0) {
							char_code = 'ASCII';
						} else if (data.indexOf('0x4a,0x49,0x53,0x00,0x00,0x00,0x00,0x00') == 0) {
							char_code = 'JIS';
						} else if (data.indexOf('0x55,0x4e,0x49,0x43,0x4f,0x44,0x45,0x00') == 0) {
							char_code = 'Unicode';
						} else if (data.indexOf('0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00') == 0) {
							char_code = 'not defined';
						}
					}
					output = getFormattedPString('x9286_1', [data , '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' , getPString(char_code)]);
					if (char_code == 'ASCII') {
						output += getFormattedPString('x9286_2', ['<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>' , bytesToString(data.substr(8*5))]);
					}
				}
				break;
			case 0x9290:	// SubsecTime (Exif IFD)
				output = getFormattedPString('x9290', [data]);
				break;
			case 0x9291:	// SubsecTimeOriginal (Exif IFD)
				output = getFormattedPString('x9291', [data]);
				break;
			case 0x9292:	// SubsecTimeDigitized (Exif IFD)
				output = getFormattedPString('x9292', [data]);
				break;
			case 0xA000:	// FlashpixVersion (Exif IFD)
				output = getFormattedPString('xA000', [bytesToString(data)]);
				break;
			case 0xA001:	// ColorSpace (Exif IFD)
				var ColorSpaces = new Array();
				ColorSpaces[-1] = 'uncalibrated (-1)';
				ColorSpaces[1] = 'sRGB (1)';
				ColorSpaces[255] = 'uncalibrated (255)';
				ColorSpaces[4294967295] = 'uncalibrated (4294967295)';
				output = getFormattedPString('xA001', [ColorSpaces[data] ? getPString(ColorSpaces[data]) : data]);
				break;
			case 0xA002:	// PixelXDimension (Exif IFD)
				output = getFormattedPString('xA002', [data]);
				break;
			case 0xA003:	// PixelYDimension (Exif IFD)
				output = getFormattedPString('xA003', [data]);
				break;
			case 0xA004:	// RelatedSoundFile (Exif IFD)
				output = getFormattedPString('xA004', [data]);
				break;
			case 0xA20B:	// FlashEnergy (Exif IFD)
				output = getFormattedPString('xA20B', [data]);
				break; 	
			case 0xA20C:	// SpatialFrequencyResponse (Exif IFD)
				// like 0xA302
				output = getFormattedPString('xA20C', [data]);
				break; 	
			case 0xA20E:	// FocalPlaneXResolution (Exif IFD)
				output = getFormattedPString('xA20E', [data , formatRational(data, 2)]);
				break; 
			case 0xA20F:	// FocalPlaneYResolution (Exif IFD)
				output = getFormattedPString('xA20F', [data , formatRational(data, 2)]);
				break;
			case 0xA210:	// FocalPlaneResolutionUnit (Exif IFD)
				var FPUnits = new Array('n/a (0)', 'none (1)', 'inch (2)', 'centimeter (3)'); 
				output = getFormattedPString('xA210', [getPString(FPUnits[data])]);
				break;
			case 0xA214:	// SubjectLocation (Exif IFD)
				output = getFormattedPString('xA214', [data]);
				break;
			case 0xA215:	// ExposureIndex (Exif IFD)
				output = getFormattedPString('xA215', [data]);
				break;
			case 0xA217:	// SensingMethod (Exif IFD)
				var SensingMethods = new Array('n/a (0)', 'n/a (1)', 'one-chip color area sensor (2)',
									 'two-chip color area sensor (3)', 'three-chip color area sensor (4)',
									 'color sequential area sensor (5)', 'n/a', 'trilinear sensor (7)',
									 'color sequential linear sensor (8)');
				output = getFormattedPString('xA217', [SensingMethods[data] ? getPString(SensingMethods[data]) : data]);
				break;
			case 0xA300:	// FileSource (Exif IFD)
				output = getFormattedPString('xA300', [data == '0x03,0x00,0x00,0x00'  ||  data == '3' ? getPString('digital still camera (DSC)') : data]);
				break;
			case 0xA301:	// SceneType (Exif IFD)
				output = getFormattedPString('xA301', [data == '0x01,0x00,0x00,0x00'  ||  data == '1' ? getPString('directly photographed image') : data]);
				break;
			case 0xA302:	// CFAPattern (Exif IFD)
				// 1st 2 bytes = horizontal array length
				// 2nd 2 bytes = vertical array length
				// next bytes are the color values, row by row (123456 => Red/Green/Blue/Cyan/Magenta/Yellow/White)
				output = getFormattedPString('xA302', [data]);
				break;
			case 0xA401:	// CustomRendered (Exif IFD)
				var CustomRenders = new Array('normal process (0)', 'custom process (1)');
				output = getFormattedPString('xA401', [getPString(CustomRenders[data])]);
				break;
			case 0xA402:	// ExposureMode (Exif IFD)
				var ExposureModes = new Array('auto exposure (0)', 'manual exposure (1)', 'auto bracket (2)');
				output = getFormattedPString('xA402', [getPString(ExposureModes[data])]);
				break;
			case 0xA403:	// WhiteBalance (Exif IFD)
				var WhiteBalances = new Array('auto (0)', 'manual (1)');
				output = getFormattedPString('xA403', [getPString(WhiteBalances[data])]);
				break; 
			case 0xA404:	// DigitalZoomRatio (Exif IFD)
				output = getFormattedPString('xA404', [data , formatRational(data, 2)]);
				break;
			case 0xA405:	// FocalLengthIn35mmFilm (Exif IFD)
				output = getFormattedPString('xA405', [data]);
				break;
			case 0xA406:	// SceneCaptureType (Exif IFD)
				var SceneCaptureTypes = new Array('standard (0)', 'landscape (1)', 'portrait (2)', 'night scene (3)');
				output = getFormattedPString('xA406', [getPString(SceneCaptureTypes[data])]);
				break;
			case 0xA407:	// GainControl (Exif IFD)
				var GainControls = new Array('n/a (0)', 'low gain up (1)', 'high gain up (2)', 
									'low gain down (3)', 'high gain down (4)');  
				output = getFormattedPString('xA407', [getPString(GainControls[data])]);
				break;
			case 0xA408:	// Contrast (Exif IFD)
				var Contrasts = new Array('normal (0)', 'soft (1)', 'hard (2)');
				output = getFormattedPString('xA408', [getPString(Contrasts[data])]);
				break;
			case 0xA409:	// Saturation (Exif IFD)
				var Saturations = new Array('normal (0)', 'low (1)', 'high (2)');
				output = getFormattedPString('xA409', [getPString(Saturations[data])]);
				break;
			case 0xA40A:	// Sharpness (Exif IFD)
				var Sharpnesses = new Array('normal (0)', 'soft (1)', 'hard (2)');
				output = getFormattedPString('xA40A', [getPString(Sharpnesses[data])]);
				break;
			case 0xA40B:	// DeviceSettingDescription (Exif IFD)
				// like 0xA302 
				output = getFormattedPString('xA40B', [data]);
				break;
			case 0xA40C:	// SubjectDistanceRange (Exif IFD)
				var SubjectDistanceRanges = new Array('unknown (0)', 'macro (1)', 
						'close view (2)', 'distant view (3)');
				output = getFormattedPString('xA40C', [getPString(SubjectDistanceRanges[data])]);
				break;
			case 0xA420:	// ImageUniqueID (Exif IFD)
				output = getFormattedPString('xA420', [data]);
				break;
			default:
				output = getFormattedPString('unknownTag', [zeroPad(tagnum) , data]);
				break;
			}
	return output; 
}	// getExifInterpretedTagData()

function getExifTagNumber(text) {
	var ExifTags = {
		"ImageWidth" : 					0x0100 ,
		"ImageLength" : 				0x0101 ,
		"BitsPerSample" : 				0x0102 ,
		"Compression" : 				0x0103 ,
		"PhotometricInterpretation" :	0x0106 ,
		"FillOrder" : 					0x010A ,
		"DocumentName" : 				0x010D ,
		"ImageDescription" : 			0x010E ,
		"Make" : 						0x010F ,
		"Model" : 						0x0110 ,
		"StripOffsets" : 				0x0111 ,
		"Orientation" : 				0x0112 ,
		"SamplesPerPixel" : 			0x0115 ,
		"RowsPerStrip" : 				0x0116 ,
		"StripByteCounts" : 			0x0117 ,
		"XResolution" : 				0x011A ,
		"YResolution" : 				0x011B ,
		"PlanarConfiguration" : 		0x011C ,
		"ResolutionUnit" : 				0x0128 ,
		"TransferFunction" : 			0x012D ,
		"Software" : 					0x0131 ,
		"DateTime" : 					0x0132 ,
		"Artist" : 						0x013B ,
		"WhitePoint" : 					0x013E ,
		"PrimaryChromaticities" : 		0x013F ,
		"TransferRange" : 				0x0156 ,
		"JPEGProc" : 					0x0200 ,
		"JPEGInterchangeFormat" : 		0x0201 ,
		"JPEGInterchangeFormatLength" : 0x0202 ,
		"YCbCrCoefficients" : 			0x0211 ,
		"YCbCrSubSampling" : 			0x0212 ,
		"YCbCrPositioning" : 			0x0213 ,
		"ReferenceBlackWhite" : 		0x0214 ,
		"BatteryLevel" : 				0x828F ,
		"Copyright" : 					0x8298 ,
		"ExposureTime" : 				0x829A ,
		"FNumber" : 					0x829D ,
		"IPTC/NAA" : 					0x83BB ,
		"ExifIFDPointer" : 				0x8769 ,
		"InterColorProfile" : 			0x8773 ,
		"ExposureProgram" : 			0x8822 ,
		"SpectralSensitivity" : 		0x8824 ,
		"GPSInfoIFDPointer" : 			0x8825 ,
		"ISOSpeedRatings" : 			0x8827 ,
		"OECF" : 						0x8828 ,
		"ExifVersion" : 				0x9000 ,
		"DateTimeOriginal" : 			0x9003 ,
		"DateTimeDigitized" : 			0x9004 ,
		"ComponentsConfiguration" : 	0x9101 ,
		"CompressedBitsPerPixel" : 		0x9102 ,
		"ShutterSpeedValue" : 			0x9201 ,
		"ApertureValue" : 				0x9202 ,
		"BrightnessValue" : 			0x9203 ,
		"ExposureBiasValue" : 			0x9204 ,
		"MaxApertureValue" : 			0x9205 ,
		"SubjectDistance" : 			0x9206 ,
		"MeteringMode" : 				0x9207 ,
		"LightSource" : 				0x9208 ,
		"Flash" : 						0x9209 ,
		"FocalLength" : 				0x920A ,
		"SubjectArea" : 				0x9214 ,
		"MakerNote" : 					0x927C ,
		"UserComment" : 				0x9286 ,
		"SubSecTime" : 					0x9290 ,
		"SubSecTimeOriginal" : 			0x9291 ,
		"SubSecTimeDigitized" : 		0x9292 ,
		"FlashpixVersion" : 			0xA000 ,
		"ColorSpace" : 					0xA001 ,
		"PixelXDimension" : 			0xA002 ,
		"PixelYDimension" : 			0xA003 ,
		"RelatedSoundFile" : 			0xA004 ,
		"InteroperabilityIFDPointer" : 	0xA005 ,
		"FlashEnergy" : 				0xA20B ,	// 0x920B in TIFF/EP
		"SpatialFrequencyResponse" :	0xA20C ,	// 0x920C    -  -
		"FocalPlaneXResolution" : 		0xA20E ,	// 0x920E    -  -
		"FocalPlaneYResolution" : 		0xA20F ,	// 0x920F    -  -
		"FocalPlaneResolutionUnit" : 	0xA210 ,	// 0x9210    -  -
		"SubjectLocation" : 			0xA214 ,	// 0x9214    -  -
		"ExposureIndex" : 				0xA215 ,	// 0x9215    -  -
		"SensingMethod" : 				0xA217 ,	// 0x9217    -  -
		"FileSource" : 					0xA300 ,
		"SceneType" : 					0xA301 ,
		"CFAPattern" : 					0xA302 ,	// 0x828E in TIFF/EP
		"CustomRendered" : 				0xA401 ,
		"ExposureMode" : 				0xA402 ,
		"WhiteBalance" : 				0xA403 ,
		"DigitalZoomRatio" : 			0xA404 ,
		"FocalLengthIn35mmFilm" : 		0xA405 ,
		"SceneCaptureType" : 			0xA406 ,
		"GainControl" : 				0xA407 ,
		"Contrast" : 					0xA408 ,
		"Saturation" : 					0xA409 ,
		"Sharpness" : 					0xA40A ,
		"DeviceSettingDescription" : 	0xA40B ,
		"SubjectDistanceRange" : 		0xA40C ,
		"ImageUniqueID" : 				0xA420
	};
	return ExifTags[text]; 
}	// getExifTagNumber()

function getExifIOPTagNumber(text) {
	var IOPTags = {
		"InteroperabilityIndex" : 	0x0001 ,
		"InteroperabilityVersion" :	0x0002 ,
		"RelatedImageFileFormat" : 	0x1000 ,
		"RelatedImageWidth" : 		0x1001 ,
		"RelatedImageLength" : 		0x1002
	};
	return IOPTags[text];
}	// getExifIOPTagNumber()

function getExifGPSTagNumber(text) {
	var GPSTags = {
		"GPSVersionID" : 		0x00 ,
		"GPSLatitudeRef" : 		0x01 ,
		"GPSLatitude" : 		0x02 ,
		"GPSLongitudeRef" : 	0x03 ,
		"GPSLongitude" : 		0x04 ,
		"GPSAltitudeRef" : 		0x05 ,
		"GPSAltitude" : 		0x06 ,
		"GPSTimeStamp" : 		0x07 ,
		"GPSSatellites" : 		0x08 ,
		"GPSStatus" : 			0x09 ,
		"GPSMeasureMode" : 		0x0A ,
		"GPSDOP" : 				0x0B ,
		"GPSSpeedRef" : 		0x0C ,
		"GPSSpeed" : 			0x0D ,
		"GPSTrackRef" : 		0x0E ,
		"GPSTrack" : 			0x0F ,
		"GPSImgDirectionRef" :	0x10 ,
		"GPSImgDirection" : 	0x11 ,
		"GPSMapDatum" : 		0x12 ,
		"GPSDestLatitudeRef" : 	0x13 ,
		"GPSDestLatitude" : 	0x14 ,
		"GPSDestLongitudeRef" :	0x15 ,
		"GPSDestLongitude" : 	0x16 ,
		"GPSDestBearingRef" : 	0x17 ,
		"GPSDestBearing" : 		0x18 ,
		"GPSDestDistanceRef" : 	0x19 ,
		"GPSDestDistance" : 	0x1A ,
		"GPSProcessingMethod" :	0x1B ,
		"GPSAreaInformation" : 	0x1C ,
		"GPSDateStamp" : 		0x1D ,
		"GPSDifferential" : 	0x1E 
	};
	return GPSTags[text];
}	// getExifGPSTagNumber()

var exifasr_basicTags = {};

exifasr_basicTags[0x010F] = "Make";
exifasr_basicTags[0x0110] = "Model";
exifasr_basicTags[0x0112] = "Orientation";
exifasr_basicTags[0x0132] = "DateTime";
exifasr_basicTags[0x829A] = "ExposureTime";
exifasr_basicTags[0x829D] = "FNumber";
exifasr_basicTags[0x8827] = "ISOSpeedRatings";
exifasr_basicTags[0x9003] = "DateTimeOriginal";
exifasr_basicTags[0x9201] = "ShutterSpeedValue";
exifasr_basicTags[0x9202] = "ApertureValue";
exifasr_basicTags[0x9209] = "Flash";
exifasr_basicTags[0x920A] = "FocalLength";
exifasr_basicTags[0xA002] = "Image Width";
exifasr_basicTags[0xA003] = "Image Height";
